<?php
/**
 * petitspapiers2017 functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package petitspapiers2017
 */

if ( ! function_exists( 'petitspapiers2017_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function petitspapiers2017_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on petitspapiers2017, use a find and replace
	 * to change 'petitspapiers2017' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'petitspapiers2017', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in 2 locations.
	register_nav_menus( array(
		'menu-1' => esc_html__( 'Menu principal', 'petitspapiers2017' ),
		'menu-2' => esc_html__( 'Menu du pied de page', 'petitspapiers2017' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'petitspapiers2017_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
}
endif;
add_action( 'after_setup_theme', 'petitspapiers2017_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function petitspapiers2017_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'petitspapiers2017_content_width', 640 );
}
add_action( 'after_setup_theme', 'petitspapiers2017_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function petitspapiers2017_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'petitspapiers2017' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'petitspapiers2017' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'petitspapiers2017_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function petitspapiers2017_scripts() {
	wp_enqueue_style( 'petitspapiers2017-style', get_stylesheet_uri() );

	wp_enqueue_script( 'petitspapiers2017-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'petitspapiers2017-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	wp_enqueue_script( 'latest-jquery', 'http://code.jquery.com/jquery-latest.js', array(), '20170528', true );

    wp_enqueue_script( 'custom-square-category-posts', get_stylesheet_directory_uri() . '/js/vignettes-proportionnelles.js', array(), '20170528', true );

    wp_enqueue_script( 'custom-unnested-menu', get_stylesheet_directory_uri() . '/js/menu-sans-imbrication.js', array(), '20170528', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'petitspapiers2017_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

class Skywalker extends Walker_Nav_Menu {

	// Walker qui n'affiche que la branche de la page courante...
    function walk( $elements, $max_depth) {

        $args = array_slice(func_get_args(), 2);
        $output = '';

        if ($max_depth < -1) //invalid parameter
            return $output;

        if (empty($elements)) //nothing to walk
            return $output;

        $id_field = $this->db_fields['id'];
        $parent_field = $this->db_fields['parent'];

        // flat display
        if ( -1 == $max_depth ) {
            $empty_array = array();
            foreach ( $elements as $e )
                $this->display_element( $e, $empty_array, 1, 0, $args, $output );
            return $output;
        }

        /*
         * need to display in hierarchical order
         * separate elements into two buckets: top level and children elements
         * children_elements is two dimensional array, eg.
         * children_elements[10][] contains all sub-elements whose parent is 10.
         */
        $top_level_elements = array();
        $children_elements  = array();
        foreach ( $elements as $e) {
            if ( 0 == $e->$parent_field )
                $top_level_elements[] = $e;
            else
                $children_elements[ $e->$parent_field ][] = $e;
        }

        /*
         * when none of the elements is top level
         * assume the first one must be root of the sub elements
         */
        if ( empty($top_level_elements) ) {

            $first = array_slice( $elements, 0, 1 );
            $root = $first[0];

            $top_level_elements = array();
            $children_elements  = array();
            foreach ( $elements as $e) {
                if ( $root->$parent_field == $e->$parent_field )
                    $top_level_elements[] = $e;
                else
                    $children_elements[ $e->$parent_field ][] = $e;
            }
        }

        $current_element_markers = array( 'current-menu-item', 'current-menu-parent', 'current-menu-ancestor' );  //added by continent7
        foreach ( $top_level_elements as $e ){  //changed by continent7
            // descend only on current tree
            $descend_test = array_intersect( $current_element_markers, $e->classes );
            if ( !empty( $descend_test ) ) 
                $this->display_element( $e, $children_elements, 2, 0, $args, $output );
        }

        /*
         * if we are displaying all levels, and remaining children_elements is not empty,
         * then we got orphans, which should be displayed regardless
         */
         /* removed by continent7
        if ( ( $max_depth == 0 ) && count( $children_elements ) > 0 ) {
            $empty_array = array();
            foreach ( $children_elements as $orphans )
                foreach( $orphans as $op )
                    $this->display_element( $op, $empty_array, 1, 0, $args, $output );
         }
        */
         return $output;
    }
}

// Ajouter une option de customisation dans le thème directement dans le backend wordpress (apparence)
// Voir: http://buildwpyourself.com/wordpress-theme-customizer/
// Et:   http://buildwpyourself.com/building-theme-color-options-customizer/

add_action( 'customize_register', 'papiersdalex_customizer' );

function papiersdalex_customizer( $wp_customize ) {

    //Enlever des réglages pré-existants dont on aura pas besoin:
    $wp_customize->remove_control('header_textcolor');

    // Créer une section de réglages
    // si la section ne contient pas d'options, elle ne va pas s'afficher
    $wp_customize->add_section( 'papiersdalex_options_section' , array(
        'title'      => __( 'Options de papiersdalex', 'papiersdalex' ),
        'priority'   => 200,
    ) );


    //==================(Option 1)==================//
    $wp_customize->add_setting( 'papiersdalex_highlight_color', array( 
        'default' => 'mediumaquamarine' 
    ) );

    // Paramètres et ajout de l'option dans une section déjà existante
    $wp_customize->add_control( 'papiersdalex_highlight_color', array(
        'label'     => __( 'Couleur principale', 'papiersdalex' ), // Texte qui va s'afficher
        'section'   => 'colors', // Dans quelle section mettre l'option - ici déjà existante
        'type'      => 'color', // Type d'option (case à cocher, menu déroulant, nuancier...)
        'priority'  => 1 // Ordre dans lequel l'option doit se mettre dans la liste de sa section
    ) );


    //==================(Option 2)==================//
    $wp_customize->add_setting( 'papiersdalex_text_color', array( 
        'default' => 'black' 
    ) );

    // Paramètres et ajout de l'option dans une section déjà existante
    $wp_customize->add_control( 'papiersdalex_text_color', array(
        'label'     => __( 'Couleur du texte', 'papiersdalex' ), // Texte qui va s'afficher
        'section'   => 'colors', // Dans quelle section mettre l'option - ici déjà existante
        'type'      => 'color', // Type d'option (case à cocher, menu déroulant, nuancier...)
        'priority'  => 99 // Ordre dans lequel l'option doit se mettre dans la liste de sa section
    ) );


    //==================(Option 3)==================//
    $wp_customize->add_setting( 'papiersdalex_contrast_color', array( 
        'default' => 'darkcyan' 
    ) );

    // Paramètres et ajout de l'option dans une section déjà existante
    $wp_customize->add_control( 'papiersdalex_contrast_color', array(
        'label'     => __( 'Couleur de contraste pour le texte', 'papiersdalex' ), // Texte qui va s'afficher
        'section'   => 'colors', // Dans quelle section mettre l'option - ici déjà existante
        'type'      => 'color', // Type d'option (case à cocher, menu déroulant, nuancier...)
        'priority'  => 100 // Ordre dans lequel l'option doit se mettre dans la liste de sa section
    ) );    
}


add_action( 'wp_head', 'papiersdalex_customizer_head_styles' );

function papiersdalex_customizer_head_styles() {
    $highlight_color = get_theme_mod( 'papiersdalex_highlight_color' ); 
    $text_color = get_theme_mod( 'papiersdalex_text_color' ); 
    $contrast_color = get_theme_mod( 'papiersdalex_contrast_color' ); 
    
    if (
        ($highlight_color != 'mediumaquamarine' && !empty($highlight_color))
        || ($text_color != 'black' && !empty($text_color))
        || ($contrast_color != 'darkcyan' && !empty($contrast_color))
    ) : // Si ce n'est pas la couleur par défaut
    ?>
        <style type="text/css">

            /* Text */
            body,
            .main-navigation ul li a,
            .footer-navigation ul li a,
            .main-navigation ul li a,
            .footer-navigation ul li a,
            .vignette-infos h2,
            mark{
                color: <?php echo $text_color; ?>;
            }

            a,
            a:visited,
            a:hover,
            a:focus,
            a:active{
                color: <?php echo $contrast_color; ?>;
            }

            .current-menu-item > a:hover,
            .site-navigation a:hover{
                color: <?php echo $contrast_color; ?> !important;
            }

            /* Backgrounds */
            .vignette-infos p,
            button{
                background-color: <?php echo $highlight_color; ?>;
            }

             /* Borders */
            ul:not(.sub-menu) .site-navigation a, /* seulement le 1er niveau de menu */
            .current-menu-ancestor > a,
            .current-menu-item > a,
            .current-post-ancestor > a,
            .blog .entry-content{
                border-color: <?php echo $text_color; ?>;
            }

            .site-navigation a:hover,
            .current-menu-item > a:hover,
            .current-post-ancestor > a:hover{
                border-color: <?php echo $contrast_color; ?>;
            }

            .menu-item-has-children > a:after{
                border-top: .35em solid transparent;
                border-bottom: .35em solid transparent;
                border-left: .65em solid <?php echo $text_color; ?>; /* 1er niveau */
            }

            .current-menu-ancestor > a:after,
            .current-menu-item.menu-item-has-children > a:after{
                border-left: .35em solid transparent;
                border-right: .35em solid transparent;
                border-top: .65em solid <?php echo $text_color; ?>; /* 1er niveau */
            }

            .menu-item-has-children > a:hover:after{
                border-top: .35em solid transparent;
                border-bottom: .35em solid transparent;
                border-left: .65em solid <?php echo $contrast_color; ?>; /* survol */
            }

            .current-menu-ancestor > a:hover:after,
            .current-menu-item.menu-item-has-children > a:hover:after{
                border-left: .35em solid transparent;
                border-right: .35em solid transparent;
                border-top: .65em solid <?php echo $contrast_color; ?>; /* survol */
            }

        </style>
    <?php
    endif;
}